@@ -1,13 +1,13 @@
 package Jasmine::Spy;
 # ABSTRACT: Mocking library for perl inspired by Jasmine's spies
-$Jasmine::Spy::VERSION = '1.0';
+$Jasmine::Spy::VERSION = '1.01';
 =head1 NAME
 
 Jasmine::Spy
 
 =head1 VERSION
 
-version 1.0
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -17,11 +17,16 @@ version 1.0
 	describe "FooClass" => sub {
 		before each => sub {
 			spyOn("BarClass", "bazMethod")->andReturn("Bop");
+			spyOn("BarClass", "bam")->andCallThrough;
 		};
 		it "calls BarClass" => sub {
 			FooClass->doTheThing();
 			expectSpy("BarClass", "bazMethod")->toHaveBeenCalled();
 		};
+		it "calls BarClass->bat method with 'bam'" => sub {
+			FooClass->doTheThing();
+			expectSpy("BarClass", "bat")->toHaveBeenCalledWith('bam')
+		};
 		after each => sub {
 			stopSpying("BarClass");
 		};
@@ -107,6 +112,31 @@ It does also record the arguments along the way.
 
 =back
 
+=head2 Qunatifiers
+
+Quantifiers may be called on the return of either C<toHaveBeenCalled> or C<toHaveBeenCalledWith>
+to stipulate how many times the method should have been called.
+
+=over 1
+
+=item once()
+
+The method was called exactly one time
+
+=item atleast(X)
+
+Method was called atleast X times
+
+=item atMost(X)
+
+Method was not called more than X times
+
+=item exactly(X)
+
+Method was called exactly X times.
+
+=back
+
 =head1 TODO
 
 =over 1
@@ -178,7 +208,7 @@ sub getCalls {
 }
 
 package Jasmine::Spy::Instance;
-$Jasmine::Spy::Instance::VERSION = '1.0';
+$Jasmine::Spy::Instance::VERSION = '1.01';
 use warnings;
 use strict;
 use base qw(Test::Builder::Module);
@@ -377,7 +407,7 @@ sub __callsMatching {
 }
 
 package Jasmine::Spy::Instance::Calls;
-$Jasmine::Spy::Instance::Calls::VERSION = '1.0';
+$Jasmine::Spy::Instance::Calls::VERSION = '1.01';
 use Tie::Array;
 use Test::Builder::Module;
 use vars qw(@ISA);
